linux-kernel.vger.kernel.org archive mirror
 help / color / mirror / Atom feed
From: tip-bot for Babu Moger <tipbot@zytor.com>
To: linux-tip-commits@vger.kernel.org
Cc: Thomas.Lendacky@amd.com, rafael@kernel.org, hpa@zytor.com,
	corbet@lwn.net, dima@arista.com, qianyue.zj@alibaba-inc.com,
	kstewart@linuxfoundation.org, bp@suse.de, mingo@kernel.org,
	sherry.hurwitz@amd.com, tony.luck@intel.com, rian@alum.mit.edu,
	dwmw2@infradead.org, kirill.shutemov@linux.intel.com,
	linux-kernel@vger.kernel.org, puwen@hygon.cn,
	reinette.chatre@intel.com, linux-doc@vger.kernel.org,
	jpoimboe@redhat.com, davem@davemloft.net, arnd@arndb.de,
	vkuznets@redhat.com, xiaochen.shen@intel.com,
	pombredanne@nexb.com, babu.moger@amd.com,
	mchehab+samsung@kernel.org, pbonzini@redhat.com,
	akpm@linux-foundation.org, chang.seok.bae@intel.com,
	brijesh.singh@amd.com, jannh@google.com, Babu.Moger@amd.com,
	tglx@linutronix.de, mingo@redhat.com, fenghua.yu@intel.com,
	luto@kernel.org, gregkh@linuxfoundation.org,
	suravee.suthikulpanit@amd.com, jroedel@suse.de,
	peterz@infradead.org
Subject: [tip:x86/cache] x86/resctrl: Bring cbm_validate() into the resource structure
Date: Thu, 22 Nov 2018 13:48:50 -0800	[thread overview]
Message-ID: <tip-a36c5ff560fb32d17c020fa3e7f4c70f753d8834@git.kernel.org> (raw)
In-Reply-To: <20181121202811.4492-7-babu.moger@amd.com>

Commit-ID:  a36c5ff560fb32d17c020fa3e7f4c70f753d8834
Gitweb:     https://git.kernel.org/tip/a36c5ff560fb32d17c020fa3e7f4c70f753d8834
Author:     Babu Moger <Babu.Moger@amd.com>
AuthorDate: Wed, 21 Nov 2018 20:28:35 +0000
Committer:  Borislav Petkov <bp@suse.de>
CommitDate: Thu, 22 Nov 2018 20:16:19 +0100

x86/resctrl: Bring cbm_validate() into the resource structure

Bring all the functions that are different between the vendors into the
resource structure and initialize them dynamically. Add _intel suffix to
the Intel-specific functions.

cbm_validate() which does cache bitmask validation, differs between the
vendors as AMD allows non-contiguous masks. So, use separate functions
for Intel and AMD.

 [ bp: Massage commit message and fixup rdt_resource members' vertical
   alignment. ]

Signed-off-by: Babu Moger <babu.moger@amd.com>
Signed-off-by: Borislav Petkov <bp@suse.de>
Cc: Andrew Morton <akpm@linux-foundation.org>
Cc: Andy Lutomirski <luto@kernel.org>
Cc: Arnd Bergmann <arnd@arndb.de>
Cc: Brijesh Singh <brijesh.singh@amd.com>
Cc: "Chang S. Bae" <chang.seok.bae@intel.com>
Cc: David Miller <davem@davemloft.net>
Cc: David Woodhouse <dwmw2@infradead.org>
Cc: Dmitry Safonov <dima@arista.com>
Cc: Fenghua Yu <fenghua.yu@intel.com>
Cc: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
Cc: "H. Peter Anvin" <hpa@zytor.com>
Cc: Ingo Molnar <mingo@redhat.com>
Cc: Jann Horn <jannh@google.com>
Cc: Joerg Roedel <jroedel@suse.de>
Cc: Jonathan Corbet <corbet@lwn.net>
Cc: Josh Poimboeuf <jpoimboe@redhat.com>
Cc: Kate Stewart <kstewart@linuxfoundation.org>
Cc: "Kirill A. Shutemov" <kirill.shutemov@linux.intel.com>
Cc: <linux-doc@vger.kernel.org>
Cc: Mauro Carvalho Chehab <mchehab+samsung@kernel.org>
Cc: Paolo Bonzini <pbonzini@redhat.com>
Cc: Peter Zijlstra <peterz@infradead.org>
Cc: Philippe Ombredanne <pombredanne@nexb.com>
Cc: Pu Wen <puwen@hygon.cn>
Cc: <qianyue.zj@alibaba-inc.com>
Cc: "Rafael J. Wysocki" <rafael@kernel.org>
Cc: Reinette Chatre <reinette.chatre@intel.com>
Cc: Rian Hunter <rian@alum.mit.edu>
Cc: Sherry Hurwitz <sherry.hurwitz@amd.com>
Cc: Suravee Suthikulpanit <suravee.suthikulpanit@amd.com>
Cc: Thomas Gleixner <tglx@linutronix.de>
Cc: Thomas Lendacky <Thomas.Lendacky@amd.com>
Cc: Tony Luck <tony.luck@intel.com>
Cc: Vitaly Kuznetsov <vkuznets@redhat.com>
Cc: <xiaochen.shen@intel.com>
Link: https://lkml.kernel.org/r/20181121202811.4492-7-babu.moger@amd.com
---
 arch/x86/kernel/cpu/resctrl/core.c        |  9 ++++++++-
 arch/x86/kernel/cpu/resctrl/ctrlmondata.c |  4 ++--
 arch/x86/kernel/cpu/resctrl/internal.h    | 15 +++++++++------
 3 files changed, 19 insertions(+), 9 deletions(-)

diff --git a/arch/x86/kernel/cpu/resctrl/core.c b/arch/x86/kernel/cpu/resctrl/core.c
index 3bd245b057c4..ba5a5b8c4681 100644
--- a/arch/x86/kernel/cpu/resctrl/core.c
+++ b/arch/x86/kernel/cpu/resctrl/core.c
@@ -878,7 +878,14 @@ static __init void rdt_init_res_defs_intel(void)
 	struct rdt_resource *r;
 
 	for_each_rdt_resource(r) {
-		if (r->rid == RDT_RESOURCE_MBA) {
+		if (r->rid == RDT_RESOURCE_L3 ||
+		    r->rid == RDT_RESOURCE_L3DATA ||
+		    r->rid == RDT_RESOURCE_L3CODE ||
+		    r->rid == RDT_RESOURCE_L2 ||
+		    r->rid == RDT_RESOURCE_L2DATA ||
+		    r->rid == RDT_RESOURCE_L2CODE)
+			r->cbm_validate = cbm_validate_intel;
+		else if (r->rid == RDT_RESOURCE_MBA) {
 			r->msr_base = MSR_IA32_MBA_THRTL_BASE;
 			r->msr_update = mba_wrmsr_intel;
 			r->parse_ctrlval = parse_bw_intel;
diff --git a/arch/x86/kernel/cpu/resctrl/ctrlmondata.c b/arch/x86/kernel/cpu/resctrl/ctrlmondata.c
index a8ae87e756e9..d2e0b99d453f 100644
--- a/arch/x86/kernel/cpu/resctrl/ctrlmondata.c
+++ b/arch/x86/kernel/cpu/resctrl/ctrlmondata.c
@@ -88,7 +88,7 @@ int parse_bw_intel(struct rdt_parse_data *data, struct rdt_resource *r,
  *	are allowed (e.g. FFFFH, 0FF0H, 003CH, etc.).
  * Additionally Haswell requires at least two bits set.
  */
-static bool cbm_validate(char *buf, u32 *data, struct rdt_resource *r)
+bool cbm_validate_intel(char *buf, u32 *data, struct rdt_resource *r)
 {
 	unsigned long first_bit, zero_bit, val;
 	unsigned int cbm_len = r->cache.cbm_len;
@@ -148,7 +148,7 @@ int parse_cbm(struct rdt_parse_data *data, struct rdt_resource *r,
 		return -EINVAL;
 	}
 
-	if (!cbm_validate(data->buf, &cbm_val, r))
+	if (r->cbm_validate && !r->cbm_validate(data->buf, &cbm_val, r))
 		return -EINVAL;
 
 	if ((rdtgrp->mode == RDT_MODE_EXCLUSIVE ||
diff --git a/arch/x86/kernel/cpu/resctrl/internal.h b/arch/x86/kernel/cpu/resctrl/internal.h
index 9a643f444723..599cad34a6a8 100644
--- a/arch/x86/kernel/cpu/resctrl/internal.h
+++ b/arch/x86/kernel/cpu/resctrl/internal.h
@@ -396,9 +396,9 @@ struct rdt_parse_data {
  * struct rdt_resource - attributes of an RDT resource
  * @rid:		The index of the resource
  * @alloc_enabled:	Is allocation enabled on this machine
- * @mon_enabled:		Is monitoring enabled for this feature
+ * @mon_enabled:	Is monitoring enabled for this feature
  * @alloc_capable:	Is allocation available on this machine
- * @mon_capable:		Is monitor feature available on this machine
+ * @mon_capable:	Is monitor feature available on this machine
  * @name:		Name to use in "schemata" file
  * @num_closid:		Number of CLOSIDs available
  * @cache_level:	Which cache level defines scope of this resource
@@ -410,10 +410,11 @@ struct rdt_parse_data {
  * @cache:		Cache allocation related data
  * @format_str:		Per resource format string to show domain value
  * @parse_ctrlval:	Per resource function pointer to parse control values
  * @evt_list:			List of monitoring events
  * @num_rmid:			Number of RMIDs available
  * @mon_scale:			cqm counter * mon_scale = occupancy in bytes
  * @fflags:			flags to choose base and info files
  */
 struct rdt_resource {
 	int			rid;
@@ -436,6 +437,7 @@ struct rdt_resource {
 	int (*parse_ctrlval)(struct rdt_parse_data *data,
 			     struct rdt_resource *r,
 			     struct rdt_domain *d);
+	bool (*cbm_validate)(char *buf, u32 *data, struct rdt_resource *r);
 	struct list_head	evt_list;
 	int			num_rmid;
 	unsigned int		mon_scale;
@@ -576,5 +578,6 @@ void cqm_setup_limbo_handler(struct rdt_domain *dom, unsigned long delay_ms);
 void cqm_handle_limbo(struct work_struct *work);
 bool has_busy_rmid(struct rdt_resource *r, struct rdt_domain *d);
 void __check_limbo(struct rdt_domain *d, bool force_free);
+bool cbm_validate_intel(char *buf, u32 *data, struct rdt_resource *r);
 
 #endif /* _ASM_X86_RESCTRL_INTERNAL_H */
@@ -410,10 +410,11 @@ struct rdt_parse_data {
  * @format_str:		Per resource format string to show domain value
  * @parse_ctrlval:	Per resource function pointer to parse control values
- * @evt_list:			List of monitoring events
- * @num_rmid:			Number of RMIDs available
- * @mon_scale:			cqm counter * mon_scale = occupancy in bytes
- * @fflags:			flags to choose base and info files
+ * @cbm_validate	Cache bitmask validate function
+ * @evt_list:		List of monitoring events
+ * @num_rmid:		Number of RMIDs available
+ * @mon_scale:		cqm counter * mon_scale = occupancy in bytes
+ * @fflags:		flags to choose base and info files
  */
 struct rdt_resource {

  reply	other threads:[~2018-11-22 21:49 UTC|newest]

Thread overview: 43+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2018-11-21 20:28 [PATCH v9 00/13] arch/resctrl: AMD QoS support Moger, Babu
2018-11-21 20:28 ` [PATCH v9 01/13] x86/resctrl: Rename and move rdt files to new directory Moger, Babu
2018-11-22 18:06   ` Borislav Petkov
2018-11-22 21:45   ` [tip:x86/cache] x86/resctrl: Rename and move rdt files to a separate directory tip-bot for Babu Moger
2018-11-23  7:28   ` [PATCH v9 01/13] x86/resctrl: Rename and move rdt files to new directory Ingo Molnar
2018-11-23  8:22     ` Borislav Petkov
2018-11-23  8:41       ` Ingo Molnar
2018-11-23  9:00         ` Borislav Petkov
2018-11-23 11:41           ` Ingo Molnar
2018-11-23 12:43             ` Thomas Gleixner
2018-11-26 18:31           ` Luck, Tony
2018-11-26 19:05             ` Borislav Petkov
2018-12-23 18:27   ` [PATCH v9 00/13] arch/resctrl: AMD QoS support Jan Engelhardt
2018-12-26 17:14     ` Moger, Babu
2018-11-21 20:28 ` [PATCH v9 02/13] x86/resctrl: Rename the RDT functions and definitions Moger, Babu
2018-11-22 21:46   ` [tip:x86/cache] " tip-bot for Babu Moger
2018-11-21 20:28 ` [PATCH v9 03/13] x86/resctrl: Re-arrange RDT init code Moger, Babu
2018-11-22 21:47   ` [tip:x86/cache] x86/resctrl: Re-arrange the " tip-bot for Babu Moger
2018-11-21 20:28 ` [PATCH v9 04/13] x86/resctrl: Bring all the macros to resctrl/internal.h Moger, Babu
2018-11-22 21:47   ` [tip:x86/cache] x86/resctrl: Move " tip-bot for Babu Moger
2018-11-21 20:28 ` [PATCH v9 05/13] x86/resctrl: Initialize the resource functions that are different Moger, Babu
2018-11-22 21:48   ` [tip:x86/cache] x86/resctrl: Initialize the vendor-specific resource functions tip-bot for Babu Moger
2018-11-21 20:28 ` [PATCH v9 06/13] x86/resctrl: Bring cbm_validate function into the resource structure Moger, Babu
2018-11-22 21:48   ` tip-bot for Babu Moger [this message]
2018-11-21 20:28 ` [PATCH v9 07/13] x86/resctrl: Add vendor check for MBA software controller Moger, Babu
2018-11-22 21:49   ` [tip:x86/cache] x86/resctrl: Add vendor check for the " tip-bot for Babu Moger
2018-11-21 20:28 ` [PATCH v9 08/13] x86/resctrl: Rename config parameter INTEL_RDT to RESCTRL Moger, Babu
2018-11-22 18:46   ` Borislav Petkov
2018-11-22 21:49   ` [tip:x86/cache] x86/resctrl: Rename the config option " tip-bot for Babu Moger
2018-11-21 20:28 ` [PATCH v9 09/13] x86/resctrl: Add AMD feature bit X86_FEATURE_MBA in cpuid bits array Moger, Babu
2018-11-22 21:50   ` [tip:x86/cache] x86/resctrl: Add AMD's X86_FEATURE_MBA to the scattered CPUID features tip-bot for Sherry Hurwitz
2018-11-21 20:28 ` [PATCH v9 10/13] x86/resctrl: Fix the messages in rdt_last_cmd_printf and rdt_last_cmd_puts Moger, Babu
2018-11-22 21:51   ` [tip:x86/cache] x86/resctrl: Fixup the user-visible strings tip-bot for Babu Moger
2018-11-26 22:16   ` [PATCH v9 10/13] x86/resctrl: Fix the messages in rdt_last_cmd_printf and rdt_last_cmd_puts Reinette Chatre
2018-11-26 22:28     ` Borislav Petkov
2018-11-26 22:44       ` Reinette Chatre
2018-11-21 20:28 ` [PATCH v9 11/13] x86/resctrl: Introduce QOS feature for AMD Moger, Babu
2018-11-22 21:51   ` [tip:x86/cache] x86/resctrl: Introduce AMD QOS feature tip-bot for Babu Moger
2018-11-21 20:28 ` [PATCH v9 12/13] Documentation: Rename and update intel_rdt_ui.txt to resctrl_ui.txt Moger, Babu
2018-11-22 21:52   ` [tip:x86/cache] " tip-bot for Babu Moger
2018-11-25  9:07   ` [PATCH v9 12/13] " Pavel Machek
2018-11-21 20:28 ` [PATCH v9 13/13] MAINTAINERS: Update the file and documentation names in arch/x86 Moger, Babu
2018-11-22 21:52   ` [tip:x86/cache] MAINTAINERS: Update resctrl filename patterns tip-bot for Babu Moger

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=tip-a36c5ff560fb32d17c020fa3e7f4c70f753d8834@git.kernel.org \
    --to=tipbot@zytor.com \
    --cc=Thomas.Lendacky@amd.com \
    --cc=akpm@linux-foundation.org \
    --cc=arnd@arndb.de \
    --cc=babu.moger@amd.com \
    --cc=bp@suse.de \
    --cc=brijesh.singh@amd.com \
    --cc=chang.seok.bae@intel.com \
    --cc=corbet@lwn.net \
    --cc=davem@davemloft.net \
    --cc=dima@arista.com \
    --cc=dwmw2@infradead.org \
    --cc=fenghua.yu@intel.com \
    --cc=gregkh@linuxfoundation.org \
    --cc=hpa@zytor.com \
    --cc=jannh@google.com \
    --cc=jpoimboe@redhat.com \
    --cc=jroedel@suse.de \
    --cc=kirill.shutemov@linux.intel.com \
    --cc=kstewart@linuxfoundation.org \
    --cc=linux-doc@vger.kernel.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=linux-tip-commits@vger.kernel.org \
    --cc=luto@kernel.org \
    --cc=mchehab+samsung@kernel.org \
    --cc=mingo@kernel.org \
    --cc=mingo@redhat.com \
    --cc=pbonzini@redhat.com \
    --cc=peterz@infradead.org \
    --cc=pombredanne@nexb.com \
    --cc=puwen@hygon.cn \
    --cc=qianyue.zj@alibaba-inc.com \
    --cc=rafael@kernel.org \
    --cc=reinette.chatre@intel.com \
    --cc=rian@alum.mit.edu \
    --cc=sherry.hurwitz@amd.com \
    --cc=suravee.suthikulpanit@amd.com \
    --cc=tglx@linutronix.de \
    --cc=tony.luck@intel.com \
    --cc=vkuznets@redhat.com \
    --cc=xiaochen.shen@intel.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).